@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.93 date 2004-04-26
+ * version 0.94 date 2004-06-07
  * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -184,7 +184,7 @@ int addr_list_add( st_addr_list * p_addr_list, st_addr * p_src_addr, st_addr * p
   }
 
   //put new item into list
-  for( i = p_addr_list->len; i > end; i-- )
+  for( i = p_addr_list->len - 1; i > end; i-- )
     p_addr_list->p_list[i] = p_addr_list->p_list[i-1];
   p_addr_list->p_list[end] = p_item;
 
@@ -219,7 +219,7 @@ int addr_list_del( st_addr_list * p_addr_list, st_addr * p_src_addr, st_addr * p
     p_addr_list->p_list[i] = p_addr_list->p_list[i+1];
 
   //can size be decreased?
-  if( p_addr_list->len <= p_addr_list->size )
+  if( p_addr_list->len + p_addr_list->size_step <= p_addr_list->size )
   {
     //decrease size
     p_addr_list->size -= p_addr_list->size_step;
@@ -301,7 +301,7 @@ void addr_list_enum_del( st_addr_list * p_addr_list, int (*enum_func)( st_addr *
   }
 
   //can size be decreased?
-  if( p_addr_list->len <= p_addr_list->size )
+  if( p_addr_list->len + p_addr_list->size_step <= p_addr_list->size )
   {
     //decrease size
     p_addr_list->size -= p_addr_list->size_step;
