@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.93 date 2004-04-26
+ * version 0.94 date 2004-06-07
  * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -184,7 +184,7 @@ int list_add( st_list * p_list, char * name, void * p_data )
   }
 
   //put new item into list
-  for( i = p_list->len; i > end; i-- )
+  for( i = p_list->len - 1; i > end; i-- )
     p_list->p_list[i] = p_list->p_list[i-1];
   p_list->p_list[end] = p_item;
 
@@ -223,7 +223,7 @@ int list_del( st_list * p_list, char * name, void (*data_free_func)( void * ) )
     p_list->p_list[i] = p_list->p_list[i+1];
 
   //can size be decreased?
-  if( p_list->len <= p_list->size )
+  if( p_list->len + p_list->size_step <= p_list->size )
   {
     //decrease size
     p_list->size -= p_list->size_step;
