@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.93 date 2004-04-26
+ * version 0.94 date 2004-06-07
  * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -89,7 +89,7 @@ int olist_add( st_olist * p_olist, unsigned int index, void * p_data )
   }
 
   //put new item into list
-  for( i = p_olist->len; i > index; i-- )
+  for( i = p_olist->len - 1; i > index; i-- )
     p_olist->p_list[i] = p_olist->p_list[i-1];
   p_olist->p_list[index] = p_data;
 
@@ -120,7 +120,7 @@ int olist_del( st_olist * p_olist, unsigned int index, void (*data_free_func)( v
     p_olist->p_list[i] = p_olist->p_list[i+1];
 
   //can size be decreased?
-  if( p_olist->len <= p_olist->size )
+  if( p_olist->len + p_olist->size_step <= p_olist->size )
   {
     //decrease size
     p_olist->size -= p_olist->size_step;
